# Le potentiel électrique

Tout comme pour le mouvement nous pouvons utiliser le concept *d'énergie* est très
important pour l'électricité. Il permet d'étendre le concept
de **conservation de l'énergie** à d'autres domaines qu'à la cinématique ou la dynamique.

## L'énergie potentielle électrique

Comme dans le cas de l'énergie mécanique, on va définir l'énergie potentielle électrique
comme on le ferait pour une force conservative. Le travail d'une force conservative entre deux points ne dépend pas
du chemin parcouru mais uniquement du point de départ et du point d'arrivée. Dans le cas
de l'énergie potentielle dûe à la force de gravité, on a que $E=m\cdot g\cdot h$ (avec $m$ la masse, $h$
la hauteur et $g$ l'accélération gravitationnelle). On sait grâce à la loi de Coulomb
que la force entre deux charges est donnée par
\begin{equation*}
F=k\frac{Q_1Q_2}{r^2}.
\end{equation*}
Comme pour l'énergie mécanique, on définit l'énergie potentielle d'un objet chargé qui se déplace entre 2 points,
$A$ et $B$ (voir @fig:epot)
comme
$$
\Delta_{EP}(A,B)=-W_{A\rightarrow B},
$$
où $\Delta_{EP}(A,B)$ est la variation d'énergie potentielle
entre les points $A$ et $B$, et $W(A\rightarrow B)$ le travail du à la force
électrostatique. Ici, le travail $W(A\rightarrow B)>0$ et donc la charge
va perdre de l'énergie potentielle.

![Le transport d'une charge positive entre $A$ et $B$ entre deux plaques chargées infinies.](figs/epot.svg){#fig:epot width=50%}

La variation d'énergie potentielle s'écrit donc
$$
\Delta_{EP}(A\rightarrow B)=E_\mathrm{pot}(B)-E_\mathrm{pot}(A).
$$
Quand une charge $q$ bouge d'un point $A$ à un point $B$ son énergie augmente
(ou diminue) comme l'inverse du travail qu'il faut à la force électrostatique
pour la déplacer de $A$ à $B$.

Ainsi Dans le cas de @fig:epot, nous sommes dans une situation où on a un
champs électrique uniforme $E$ entre deux plaques infinies.
Si on lâche la charge $q$ du point $A$,
et qu'on suppose que $q$ est suffisamment petite pour ne pas modifier
le champs électrique entre les plaques. La force électrostatique va déplacer
la charge du point $A$ au point $B$ sur une distance $d=|A-B|$ et effectuer un travail $W$
$$
W_{A\rightarrow B}=F\cdot d=q\cdot E\cdot d.
$$
Le changement d'énergie potentielle est donc
$$
E_\mathrm{pot}(B)-E_\mathrm{pot}(A)=-q\cdot E\cdot d.
$${#eq:epot}
L'énergie potentielle diminue dans ce cas (le travail est positif)
et la particule accélère naturellement du point $A$ au point $B$.
Ainsi la loi de conservation d'énergie est vérifiée:
l'énergie cinétique augmente et l'énergie potentielle (électrique) diminue
d'autant. A l'inverse si on remplace la charge $q$ par $-q$
son énergie potentielle sera augmentée lors du déplacement
de $A$ à $B$.

---

Question (Unités) #

Quelles sont les unités de l'énergie potentielle électrique?

---

---

Réponse (Unités) #

Comme pour toute énergie, les unités sont des joules, $[J]$, soit des
$$
[J]=[\mathrm{N}\cdot \mathrm{m}]=\left[\mathrm{kg}\cdot \frac{\mathrm{m}^2}{\mathrm{s}^2}\right].
$$

---

Il est important de noter que la valeur de l'énergie potentielle est relative à une valeur de référence.
En effet, comme on le voit à l'@eq:epot, on ne définit
que la différence d'énergie potentielle et pas
une valeur absolue. En général, on choisit la "valeur
de référence" de l'énergie potentielle électrique
comme une valeur où l'énergie potentielle est choisie de façon arbitraire comme étant nulle. Ceci n'est pas particulièrement choquant. En effet, c'est une pratique courante avec l'énergie potentielle (on définit le zéro
de l'énergie potentielle de gravitation à une "hauteur" zéro mais par rapport à quelle échelle de mesure?).

## Le potentiel électrique

Au chapitre précédent, nous avons défini le champs électrique
comme la force par unité de charge générée par une source.o
Ici, nous allons recommencer en définissant le **potentiel électrique**, noté $V$, comme le champs électrique par unité de charge. Ainsi si une charge, $q$, se trouve dans un champs
électrique à une position $A$, et a une énergie potentielle électrique $E_\mathrm{pot}(A)$, son **potentiel électrique**
est défini par
$$
V(A)=\frac{E_\mathrm{pot}(A)}{q}.
$$

---

Question (Unités) #

Quelles sont les unités dui potentiel électrique?

---

---

Réponse (Unités) #

Les unités du potentiel électrique sont les **volts**, $[V]$.
Ils peuvent s'exprimer en fonction des autres unités connues
comme
$$
[V]=\left[\frac{\mathrm{J}}{\mathrm{C}}\right]=\left[\frac{\mathrm{N}\cdot \mathrm{m}}{\mathrm{C}}\right]=\left[\mathrm{kg}\cdot \frac{\mathrm{m}^2}{\mathrm{s}^2\cdot \mathrm{C}}\right].
$$

---



Comme nous l'avons mentionné plus haut seule une **différence** d'énergie potentielle électrique est mesurable (il nous faut une valeur de référence).
De même seule une **différence** de potentiel électrique
peut se mesurer
$$
V(B, A)=V(B)-V(A)=\Delta_{EP}(A\rightarrow B)=\frac{E_\mathrm{pot}(B)-E_\mathrm{pot}(A)}{q}=-\frac{W_{A\rightarrow B}}{q},
$$
où $A$ et $B$ sont deux points et $W_{B\rightarrow A}$ le travail pour emmener une charge $q$ du point $B$ au point $A$.
Tout comme le champs électrique ne dépend pas de la valeur de la *charge test*, ici le potentiel ne dépend pas
de la charge test, $q$, non plus. Le potentiel électrique, $V$, ne dépend des charges qui créent le champs électrique associé. On dit que $q$ acquière l'énergie potentielle électrique en se trouvant dans le potentiel $V$ qui est créé par d'autres charges.

Pour reprendre l'exemple des plaques chargées de la @fig:epot,
on voit que la charge positive $q$ a un potentiel électrique
plus grand en $A$ qu'en $B$ et que donc elle va naturellement
se déplacer vers $B$.

---

Remarque (Référénce) #

Afin de définir le potentiel électrique en un point $A$, nous avons besoin d'une valeur de référence comme discuté plus haut. En général cette valeur est choisie arbitrairement
comme valant zéro et est le potentiel de la "terre". Tous les
autres potentiels sont donnés par rapport à cette référence.

---

---

Question (Charge négative) #

Reprenons un exemple similaire à @fig:epot, mais remplaçons la charge par une charge négative (voir @fig:epot_neg). Aussi elle se trouve au point $B$ et est libre de se déplacer.
Que va-t-il se produire? Son énergie potentielle va augmenter ou diminuer? Comment le potentiel électrique varie entre les deux points $A$ et $B$?

![Le transport d'une charge négative entre $B$ et $A$ entre deux plaques chargées infinies.](figs/epot.svg){#fig:epot_neg width=50%}

---

---

Réponse (Charge négative) #

Une charge négative va être repoussée par la plaque négative et attirée par la charge positive. Ainsi, $q$ va se déplacer vers la plaque positive, son énergie cinétique va augmenter.
A cause du principe de la conservation de l'énergie,
son énergie potentielle va donc décroître. On a que
$$
E_\mathrm{pot}(A) < E_\mathrm{pot}(B).
$$
En revanche la charge se déplace d'une d'une région avec
un potentiel élevé vers un potentiel plus faible. La variation
de potentiel électrique (qui est dûe aux plaques) est donc positive contrairement à l'énergie 
potentielle électrique
\begin{align}
&E_\mathrm{pot}(B)-E_\mathrm{pot}(A) > 0,\\
&V(B)-V(A) > 0.
\end{align}
Si la charge $q$ était positive, la variation
d'énergie potentielle aurait été négative.

---

Si on fait faire le chemin inverse à notre charge positive $q$, et qu'on la déplace de $B$ à $A$. On peut inverser la relation entre le potentiel électrique et la variation d'énergie potentielle entre les points $B$ et $A$ pour une charge $q$. On aura donc
$$
\Delta_{EP}(B\rightarrow A)=E_\mathrm{pot}(A)-E_\mathrm{pot}(B)=q\cdot V(A, B).
$$
Si la différence de potentiel est de $10\mathrm{V}$,
l'énergie potentielle d'une charge de $5\mathrm{C}$ sera augmentée de $50\mathrm{J}$.
Une charge de $10\mathrm{C}$, elle, verra son énergie potentielle électrique
augmenter de $100\mathrm{J}$ pour le même déplacement.

C'est très similaire avec ce qui se passe pour le cas de l'énergie potentielle de gravitation.
Prenons deux personnes de $m_1=50\kg$ et $m_2=100\kg$ qui monte en haut d'un immeuble de $h=20\m$.
Le potentiel dû à la gravitation est le même pour les deux en haut de l'immeuble, $g\cdot h=186\mathrm{J}$.
En revanche l'énergie potentielle de gravitation des deux objets sera différente.
Elle sera de $m_1\cdot g\cdot h\cong 980\mathrm{J}$ pour le premier objet et de
$m_2\cdot g\cdot h\cong 1860\mathrm{J}$ pour le second.



